@@ -6,9 +6,10 @@ import itertools as it
 import random as _random
 import string
 import uuid as _uuid
+from typing import Generator
 
 
-def sequential(start=1, step=1):
+def sequential(start: int = 1, step: int = 1) -> Generator[int, None, None]:
     """
     Sequential id generator. Returns consecutive values starting from `start` with step `step`.
     """
@@ -16,7 +17,7 @@ def sequential(start=1, step=1):
     yield from it.count(start, step)
 
 
-def randint(a, b):
+def randint(a: int, b: int) -> Generator[int, None, None]:
     """
     Random integer id generator. Returns random integers between `a` and `b`.
     """
@@ -25,7 +26,7 @@ def randint(a, b):
         yield _random.randint(a, b)
 
 
-def random(length=8, chars=string.digits + string.ascii_lowercase):
+def random(length: int = 8, chars: str = string.digits + string.ascii_lowercase) -> Generator[str, None, None]:
     """
     Random string id generator. Returns random strings of length `length` using alphabet `chars`.
     """
@@ -34,7 +35,7 @@ def random(length=8, chars=string.digits + string.ascii_lowercase):
         yield ''.join((_random.choice(chars) for _ in range(length)))
 
 
-def uuid():
+def uuid() -> Generator[_uuid.UUID, None, None]:
     """
     UUID id generator. Returns random UUIDs.
     """
